@@ -173,8 +173,9 @@ class DiogenesBarrel extends DiogenesPage
       $this->doPage($path, $page_title, $page_template);
     } else {
       // otherwise, we send back the raw file
-      $type = mime_content_type($path);
+      $type = get_mime_type($path);
       header("Content-Type:$type");
+      header("Content-Length:".filesize($path));
       header("Last-modified:".gmdate("D, d M Y H:i:s T", filemtime($path)));
       readfile($path);
     }
