@@ -41,6 +41,9 @@ class DiogenesPage extends DiogenesCorePage
   /** An array of items for the 'menu' area */
   var $menu = array();
 
+  /** Whether we're into kill() or not */
+  var $_dying = false;
+
   /** The constructor.
    */
   function DiogenesPage()
@@ -59,6 +62,11 @@ class DiogenesPage extends DiogenesCorePage
     $this->assign('phplayersmenu', $this->url("phplayersmenu"));
     $this->assign_by_ref('head', $this->head);
     $this->assign_by_ref('menuitems', $this->menu);
+
+    // debugging assignments
+    $this->assign('msg_debug_bar', __("debugging"));
+    $this->assign('msg_debug_calltrace', __("call trace"));
+    $this->assign('msg_debug_dbtrace', __("database trace"));
   }
 
  
@@ -178,6 +186,16 @@ class DiogenesPage extends DiogenesCorePage
    * @param $code the HTTP status code to send
    */
   function kill($msg, $code = 500) {
+    if ($this->_dying)
+    {
+      // We're in a loop of kills.  This is very, very bad.
+      // We need to bale as quick as possible, because we can't rely on
+      // *any* system code to not be the source of the kill() call.
+      echo "<h1>Very fatal error: $msg</h1>\n";
+      exit;
+    }
+    
+    $this->_dying = true;
     $this->httpStatus($code);
     $this->assign('greeting', __("Diogenes error"));
     $this->assign('page', __("Error"));
